"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.nodeToReactComponent = exports.nodeListToReactComponents = void 0;
var react_1 = __importDefault(require("react"));
var rich_text_types_1 = require("@contentful/rich-text-types");
var appendKeyToValidElement_1 = require("./appendKeyToValidElement");
function nodeListToReactComponents(nodes, options) {
    return nodes.map(function (node, index) {
        return (0, appendKeyToValidElement_1.appendKeyToValidElement)(nodeToReactComponent(node, options), index);
    });
}
exports.nodeListToReactComponents = nodeListToReactComponents;
function nodeToReactComponent(node, options) {
    var renderNode = options.renderNode, renderMark = options.renderMark, renderText = options.renderText, preserveWhitespace = options.preserveWhitespace;
    if (rich_text_types_1.helpers.isText(node)) {
        var nodeValue = renderText ? renderText(node.value) : node.value;
        if (preserveWhitespace) {
            // Preserve multiple spaces.
            nodeValue = nodeValue.replace(/ {2,}/g, function (match) { return '\u00A0'.repeat(match.length); });
            // Preserve line breaks.
            var lines_1 = nodeValue.split('\n');
            var jsxLines_1 = [];
            lines_1.forEach(function (line, index) {
                jsxLines_1.push(line);
                if (index !== lines_1.length - 1) {
                    jsxLines_1.push(react_1.default.createElement("br", null));
                }
            });
            nodeValue = jsxLines_1;
        }
        return node.marks.reduce(function (value, mark) {
            if (!renderMark[mark.type]) {
                return value;
            }
            return renderMark[mark.type](value);
        }, nodeValue);
    }
    else {
        var children = nodeListToReactComponents(node.content, options);
        if (!node.nodeType || !renderNode[node.nodeType]) {
            return react_1.default.createElement(react_1.default.Fragment, null, children);
        }
        return renderNode[node.nodeType](node, children);
    }
}
exports.nodeToReactComponent = nodeToReactComponent;
//# sourceMappingURL=nodeListToReactComponents.js.map